==> haskell-hls-stylish-haskell-plugin-1.0.1.2-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-stylish-haskell-plugin
version:              1.0.1.2
visibility:           public
id:                   hls-stylish-haskell-plugin-1.0.1.2-AlI1gD3v6v0JjyuJUaTQol
key:                  hls-stylish-haskell-plugin-1.0.1.2-AlI1gD3v6v0JjyuJUaTQol
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d4df06e7ec05fa9804263dcd670a57cc
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-1.0.1.2-AlI1gD3v6v0JjyuJUaTQol
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 ghc-9.0.2
    ghc-boot-th-9.0.2 ghcide-1.9.1.0-32Io5Wick9EBvYEsOxxi2B
    hls-plugin-api-1.6.0.0-CIEFejOti1S7uu0o2543SI
    lsp-types-1.6.0.0-JoEI09VU0k32zkggilxM2Q
    stylish-haskell-0.13.0.0-F0bR2ps9cd3Dvsljq6VACO text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-stylish-haskell-plugin-1.0.1.2-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-stylish-haskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-stylish-haskell-plugin
version:              1.0.1.2
visibility:           public
id:                   hls-stylish-haskell-plugin-1.0.1.2-Avm5LmYOncHJzrb0MlNqJA
key:                  hls-stylish-haskell-plugin-1.0.1.2-Avm5LmYOncHJzrb0MlNqJA
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Stylish Haskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f869e5364271ee92e8e58f278226180c
exposed:              True
exposed-modules:      Ide.Plugin.StylishHaskell
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-stylish-haskell-plugin-1.0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-stylish-haskell-plugin
hs-libraries:         HShls-stylish-haskell-plugin-1.0.1.2-Avm5LmYOncHJzrb0MlNqJA
depends:
    base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1 ghc-9.0.2
    ghc-boot-th-9.0.2 ghcide-1.9.1.0-6LjNtXxEsFjP6FTRfnjBs
    hls-plugin-api-1.6.0.0-AMyEr3ncypu50jLRT7GrE2
    lsp-types-1.6.0.0-LMVMp9mumPmBVlZr9rdThy
    stylish-haskell-0.13.0.0-3xiCFwoyV1x4Fj1oi6CV2t text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-stylish-haskell-plugin/html/hls-stylish-haskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-stylish-haskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
